@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aeson
-version: 0.11.1.4
-id: aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
-key: aeson_FnADcKFoDWeK9YK1Yvshsy
+version: 0.11.2.0
+id: aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
+key: aeson_33XPr26G7eRCQzR9rt6W5q
 license: BSD3
 copyright: (c) 2011-2016 Bryan O'\''Sullivan
            (c) 2011 MailRank, Inc.
@@ -46,12 +46,12 @@ hidden-modules: Data.Aeson.Encode.Builder
                 Data.Aeson.Types.Class Data.Aeson.Types.Generic
                 Data.Aeson.Types.Instances Data.Aeson.Types.Internal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-0.11.1.4
-library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-0.11.1.4
-data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-0.11.1.4
-hs-libraries: HSaeson-0.11.1.4-FnADcKFoDWeK9YK1Yvshsy
+import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-0.11.2.0
+library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-0.11.2.0
+data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-0.11.2.0
+hs-libraries: HSaeson-0.11.2.0-33XPr26G7eRCQzR9rt6W5q
 depends:
-    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
+    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
@@ -62,9 +62,9 @@ depends:
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
-    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
-    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
+    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
